@@ -27,6 +27,7 @@ def resolveAuto(config, serviceConfig, depends):
 
 def interpreteValues(args):
     depends = args['content']['depends'].replace(' ','').split(',')
+    args['config'][args['secname']]['depends'] = set(depends) if 0 < len(depends[0]) else {}
     for depend in depends:
         if depend in args['content']:
             args['config'][args['secname']][depend] = resolveAuto(args['config'], args['content'][depend].replace(' ','').split(','), depend)
@@ -46,10 +47,12 @@ def readHandlerDefault(args):
     handlerNames = handlerName.split('/')
     handler = __import__('cryptdomainmgr.modules.{}.handler{}'.format(str(args['module']), handlerNames[0]), fromlist=('cryptdomainmgr', 'modules', str(args['module'])))
     args['config'][args['secname']].update(handler.defaultConfig)
+    args['config'][args['secname']].update({'handler': handlerName})
 
 
 def interpreteConfig(cr, sh):
-    return processConfig(cr, 'service', preOp=readHandlerDefault, postOp=interpreteValues, defaultConfig={'container': 'false'})
+    return processConfig(cr, 'service', preOp=readHandlerDefault, postOp=interpreteValues, defaultConfig={'container': 'false', 'depends': ''})
+
 
 
 
